@@ -3,9 +3,7 @@
 # Assumes that data contains two variables: month and year
 # November 2009
 
-monthmean<-function(data,resp,pop=NULL,adjmonth=FALSE){
-  attach(data,warn.conflicts=FALSE)
-  on.exit(detach(data))
+monthmean<-function(data,resp,offsetpop=NULL,adjmonth=FALSE){
 # checks
   if (is.null(data)==TRUE){stop("must have an input data set (data)")}
   if (is.null(resp)==TRUE){stop("must have an input variable (resp)")}
@@ -17,10 +15,11 @@ monthmean<-function(data,resp,pop=NULL,adjmonth=FALSE){
   mean<-vector(length=12,mode='numeric')
   if (adjmonth=='thirty') adjf=30  
   if (adjmonth=='average') adjf=365.25/12
-  if (is.null(pop)==TRUE) adjp=1 else adjp=pop # population adjustment
+  if (is.null(offsetpop)==TRUE) adjp=1 else adjp=with(data,eval(offsetpop)) # population adjustment
+  xxxx=subset(data,select=resp)[,1] # instead of with
   for (i in 1:12){
-     if (adjmonth!=FALSE) mean[i]<-mean(resp[data$month==i]*(adjf/days$ndaysmonth[i])/adjp)
-     else mean[i]<-mean(resp[data$month==i]/adjp) # no monthly adjustment
+     if (adjmonth!=FALSE) mean[i]<-mean(xxxx[data$month==i]*(adjf/days$ndaysmonth[i])/adjp)
+     else mean[i]<-mean(xxxx[data$month==i]/adjp) # no monthly adjustment
   }
 # return
   toret<-list()
@@ -30,5 +29,5 @@ monthmean<-function(data,resp,pop=NULL,adjmonth=FALSE){
 }
 
 # example
-# mmean<-monthmean(data=CVD,resp=cvd,pop=pop/100000,plot=TRUE)
-# adjmean<-monthmean(data=elderly,resp=cvd,adjmonth='average',pop=pop/100000,plot=TRUE)
+# mmean<-monthmean(data=CVD,resp=cvd,offsetpop=expression(pop/100000))
+# adjmean<-monthmean(data=elderly,resp=cvd,adjmonth='average',offsetpop=expression(pop/100000))
